==> ChIPpeakAnno_2.8.0.tar.gz: ChIPpeakAnno/man/getEnrichedGO.Rd <==
\name{getEnrichedGO}
\alias{getEnrichedGO}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Obtain enriched gene ontology (GO) terms that near the peaks }
\description{
  Obtain enriched gene ontology (GO) terms that are near the peaks using GO.db package and GO gene mapping package such as org.Hs.db.eg to obtain the GO annotation and using hypergeometric test (phyper) and  multtest package for adjusting p-values
}
\usage{
getEnrichedGO(annotatedPeak, orgAnn, feature_id_type="ensembl_gene_id", 
maxP=0.01, multiAdj=FALSE, minGOterm=10, multiAdjMethod="")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{annotatedPeak}{RangedData such as data(annotatedPeak) or a vector of feature IDs }
  \item{orgAnn}{ organism annotation package such as org.Hs.eg.db for human and org.Mm.eg.db for mouse, org.Dm.eg.db for fly, org.Rn.eg.db for rat, org.Sc.eg.db for yeast and org.Dr.eg.db for zebrafish }
 \item{feature_id_type}{the feature type in annotatedPeakRanges such as ensembl_gene_id, refseq_id, gene_symbol or entrez_id}
  \item{maxP}{ maximum p-value to be considered to be significant}
  \item{multiAdj}{ Whether apply multiple hypothesis testing adjustment, TURE or FALSE }
  \item{minGOterm}{ minimum count in a genome for a GO term to be included  }
  \item{multiAdjMethod}{ multiple testing procedures, for details, see mt.rawp2adjp in multtest package}
}
\details{
  }
\value{
A list of 3
 \item{\code{bp}}{ enriched biological process with the following 9 variables

	go.id:GO biological process id
	
	go.term:GO biological process term
	
	go.Definition:GO biological process description
	
	Ontology: Ontology branch, i.e. BP for biological process

	count.InDataset: count of this GO term in this dataset

	count.InGenome: count of this GO term in the genome

	pvalue: pvalue from the hypergeometric test

	totaltermInDataset: count of all GO terms in this dataset

	totaltermInGenome: count of all GO terms in the genome

}
 \item{\code{mf}}{enriched molecular function with  the following 9 variables

	go.id:GO molecular function id
	
	go.term:GO molecular function term
	
	go.Definition:GO molecular function description
	
	Ontology: Ontology branch, i.e. MF for molecular function

	count.InDataset: count of this GO term in this dataset

	count.InGenome: count of this GO term in the genome

	pvalue: pvalue from the hypergeometric test

	totaltermInDataset: count of all GO terms in this dataset

	totaltermInGenome: count of all GO terms in the genome

}
 \item{\code{cc}}{enriched cellular component  the following 9 variables

	go.id:GO cellular component id
	
	go.term:GO cellular component term
	
	go.Definition:GO cellular component description
	
	Ontology: Ontology type, i.e. CC for cellular component

	count.InDataset: count of this GO term in this dataset

	count.InGenome: count of this GO term in the genome

	pvalue: pvalue from the hypergeometric test

	totaltermInDataset: count of all GO terms in this dataset

	totaltermInGenome: count of all GO terms in the genome

}
}
\references{ Johnson, N. L., Kotz, S., and Kemp, A. W. (1992) Univariate Discrete Distributions, Second Edition. New York: Wiley }
\author{ Lihua Julie Zhu }
\note{  

 
}
\seealso{ phyper, hyperGtest}
\examples{
data(enrichedGO)
enrichedGO$mf[1:10,]
enrichedGO$bp[1:10,]
enrichedGO$cc
if (interactive()) {
data(annotatedPeak)
library(org.Hs.eg.db)
enriched.GO = getEnrichedGO(annotatedPeak[1:6,], orgAnn="org.Hs.eg.db", maxP=0.01,
 multiAdj=FALSE, minGOterm=10, multiAdjMethod="")
 dim(enriched.GO$mf)
 colnames(enriched.GO$mf)
 dim(enriched.GO$bp)
 enriched.GO$cc
}
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ misc }

==> ChIPpeakAnno_3.2.2.tar.gz: ChIPpeakAnno/man/getEnrichedGO.Rd <==
\name{getEnrichedGO}
\alias{getEnrichedGO}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Obtain enriched gene ontology (GO) terms that near the peaks }
\description{
  Obtain enriched gene ontology (GO) terms that are near the peaks using GO.db package and GO gene mapping package such as org.Hs.db.eg to obtain the GO annotation and using hypergeometric test (phyper) and  multtest package for adjusting p-values
}
\usage{
getEnrichedGO(annotatedPeak, orgAnn, feature_id_type="ensembl_gene_id", 
maxP=0.01, multiAdj=FALSE, minGOterm=10, multiAdjMethod="")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{annotatedPeak}{RangedData or GRanges such as data(annotatedPeak) or a vector of feature IDs }
  \item{orgAnn}{ organism annotation package such as org.Hs.eg.db for human and org.Mm.eg.db for mouse, org.Dm.eg.db for fly, org.Rn.eg.db for rat, org.Sc.eg.db for yeast and org.Dr.eg.db for zebrafish }
 \item{feature_id_type}{the feature type in annotatedPeakRanges such as ensembl_gene_id, refseq_id, gene_symbol or entrez_id}
  \item{maxP}{ maximum p-value to be considered to be significant}
  \item{multiAdj}{ Whether apply multiple hypothesis testing adjustment, TURE or FALSE }
  \item{minGOterm}{ minimum count in a genome for a GO term to be included  }
  \item{multiAdjMethod}{ multiple testing procedures, for details, see mt.rawp2adjp in multtest package}
}
\value{
A list of 3
 \item{\code{bp}}{ enriched biological process with the following 9 variables

	go.id:GO biological process id
	
	go.term:GO biological process term
	
	go.Definition:GO biological process description
	
	Ontology: Ontology branch, i.e. BP for biological process

	count.InDataset: count of this GO term in this dataset

	count.InGenome: count of this GO term in the genome

	pvalue: pvalue from the hypergeometric test

	totaltermInDataset: count of all GO terms in this dataset

	totaltermInGenome: count of all GO terms in the genome

}
 \item{\code{mf}}{enriched molecular function with  the following 9 variables

	go.id:GO molecular function id
	
	go.term:GO molecular function term
	
	go.Definition:GO molecular function description
	
	Ontology: Ontology branch, i.e. MF for molecular function

	count.InDataset: count of this GO term in this dataset

	count.InGenome: count of this GO term in the genome

	pvalue: pvalue from the hypergeometric test

	totaltermInDataset: count of all GO terms in this dataset

	totaltermInGenome: count of all GO terms in the genome

}
 \item{\code{cc}}{enriched cellular component  the following 9 variables

	go.id:GO cellular component id
	
	go.term:GO cellular component term
	
	go.Definition:GO cellular component description
	
	Ontology: Ontology type, i.e. CC for cellular component

	count.InDataset: count of this GO term in this dataset

	count.InGenome: count of this GO term in the genome

	pvalue: pvalue from the hypergeometric test

	totaltermInDataset: count of all GO terms in this dataset

	totaltermInGenome: count of all GO terms in the genome

}
}
\references{ Johnson, N. L., Kotz, S., and Kemp, A. W. (1992) Univariate Discrete Distributions, Second Edition. New York: Wiley }
\author{ Lihua Julie Zhu }
\seealso{ phyper, hyperGtest}
\examples{
data(enrichedGO)
enrichedGO$mf[1:10,]
enrichedGO$bp[1:10,]
enrichedGO$cc
if (interactive()) {
data(annotatedPeak)
library(org.Hs.eg.db)
enriched.GO = getEnrichedGO(annotatedPeak[1:6,], orgAnn="org.Hs.eg.db", maxP=0.01,
 multiAdj=FALSE, minGOterm=10, multiAdjMethod="")
 dim(enriched.GO$mf)
 colnames(enriched.GO$mf)
 dim(enriched.GO$bp)
 enriched.GO$cc
}
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ misc }
